import { DateTime, type DurationUnit } from "luxon";
export interface ApplyOffsetSettings {
    /**
     * The range of DateTimes to which offsets are applied.
     */
    rangeToAdjust: DateTime[];
    /**
     * The unit of time to use with applying the offset.
     *
     * @example 'days', 'months' etc.
     */
    timeUnit: DurationUnit;
    /**
     * The number of time units to add to the start of the range.
     */
    startOffset: number;
    /**
     * The number of time units to add to the end of the range.
     */
    endOffset: number;
}
/**
 * Shifts the start or end of a date range by a given offset.
 *
 * @remarks
 * Works by adding or subtracting a specified number of time units to the
 * start or end of the range.
 *
 * @param settings - An object that contains the date range, the offsets and the time unit to apply.
 * See {@link ApplyOffsetSettings} for more details.
 * @returns A new array of DateTimes.
 * @throws ValidationError - If any of the options are invalid.
 */
export declare function applyOffset(settings: ApplyOffsetSettings): DateTime[];
